@@ -1,5 +1,9 @@
 .SP2owin <- function(SP) {
-    require(spatstat)
+    # require(spatstat)
+    if (!is.na(sp::is.projected(SP)) && !sp::is.projected(SP))
+      stop("Only projected coordinates may be converted to spatstat class objects")
+    if (!requireNamespace("spatstat", quietly = TRUE))
+	stop("package spatstat required for .SP2owin")
     pls <- slot(SP, "polygons")
     nParts <- sapply(pls, function(x) length(slot(x, "Polygons")))
     nOwin <- sum(nParts)
@@ -10,7 +14,7 @@
 	rD <- pl[[1]]@ringDir
 	if (rD == 1) crds <- crds[nrow(crds):1,]
 	crds <- crds[-nrow(crds),]
-	res <- owin(poly=list(x=crds[,1], y=crds[,2]))
+	res <- spatstat::owin(poly=list(x=crds[,1], y=crds[,2]))
     } else if (nOwin > 1) {
         opls <- vector(mode="list", length=nOwin)
         io <- 1
@@ -32,13 +36,11 @@
             }
         }
 #	if (exists(".spatstat_check") && !.spatstat_check) 
-        if (!spatstat.options("checkpolygons")) 
-        	res <- owin(bbox(SP)[1,], bbox(SP)[2,], poly = opls,
+        if (!spatstat::spatstat.options("checkpolygons")) 
+        	res <- spatstat::owin(bbox(SP)[1,], bbox(SP)[2,], poly = opls,
 			check=FALSE)
 # 070718 added check avoidance
-	else res <- owin(poly=opls)
+	else res <- spatstat::owin(poly=opls)
     } else stop("no valid polygons")
     res
 }
-
-
